##----------------------------------------------------------------------------##
##=Purpose: Exercise 2.3 of Beyond Classic Designs & Analysis for Health      ##
##          Data in Singapore (27 June to 8 July 2022)                        ##
##
##=Data required: 
##  - 2.1_framingham_exercises.dta
##  - RSV_data_exercise.dta
##
##=R packages/libraries required:
##  - dplyr: 
##    * for random sampling of controls
##  - epiDisplay: 
##    * matchTab
##  - haven:
##    * read_dta: To read in recent versions of STATA dta files.
##  - Matching:
##    * Match: to perform matched case-control 
##  - survival:
##   * clogit: conditional logistic
##
##=Created by:
##  - Francesca Graziano 
##  - Zilu Feng
##  - Zihan 
##  - Chuen Seng Tan
##  - Marie Reilly
##
##=Changes (if any):
##  -DDMMYYYY: Describe
##
##----------------------------------------------------------------------------##

##-Set the working directory to the data folder where the datasets are saved:
setwd("D:/nbox/Education/Marie_short_course/Singapore course 2022/20220602/exercises/data")

##-R libraries to install:
#install.packages(c("dplyr","epiDisplay","haven","Matching","survival))
##-Load the R libraries
library(dplyr)
library(epiDisplay)
library(haven)
library(Matching)
library(survival)

#Self-written R function to compute OR and 95%CI from matched 2x2 data 
CALC_MATCHED_OR <- function(n11,n10,n01,n00,digit=3) {
  #create an empty object named "MTAB". Info will be added to it
  MTAB <- NULL
  #make "MTAB" a 2 by 2 table
  #"byrow = T"is required as default is to fill by columns
  MTAB <- matrix(c(n11, n10, n01, n00), 
                 nrow = 2, ncol = 2, byrow = T) 
  #fill in names
  colnames(MTAB) <- c("con_Exposed", "con_unExposed")
  rownames(MTAB) <- c("case_Exposed", "case_unExposed")
  #displays the newly created table on screen
  print(MTAB)
  #calculate odds ratio
  ODDS_RATIO <- round((n10/n01),digit)
  #calculate 95% CI of odds ratio
  SE_LOG_OR <- sqrt( (1/n10) + (1/n01))
  CI_UP_LOG_OR = log(ODDS_RATIO) + 1.96*SE_LOG_OR
  CI_LOW_LOG_OR = log(ODDS_RATIO) - 1.96*SE_LOG_OR
  CI_UPPER_OR = round(exp(CI_UP_LOG_OR),digit)
  CI_LOWER_OR = round(exp(CI_LOW_LOG_OR),digit)
  print(paste("Odds ratio =", ODDS_RATIO, "(", CI_LOWER_OR, ",", CI_UPPER_OR, ")"), sep = '')
}


################################################################################
##                               Question 1      
##
##-1. Using the same data as for Exercise 2.1, generate a new age category 
##    variable with age in decades agecat2 (< 40, 40-49, 50-59, 60-70). Select 
##    a matched case-control sample of diabetes cases and one control per case, 
##    matched on agecat2. Make sure to set a "seed" before the sampling so that 
##    you can reproduce the exact same selection if necessary.
##
##    Save as a temporary data set. We will use these data to examine the 
##    association of prevalent diabetes with prevalent CHD.
################################################################################

#1- import dataset
data<- read_dta("2.1_framingham_exercises.dta")
data40<-data[data$age>=40,]

#2- match the data
#give each participant an ID
data40$id <- 1:nrow(data40)
table(data40[data40$diabetes==1,"agecat"])
dim(data40[data40$diabetes==1,"agecat"])

#using Match() function from Matching library do matching of cases
#Tr = "treatment, i.e. outcome"
#M = "number of controls to be matched per case
#X = "covariate to match using"
#exact = To indicate which variable has exact matching.
#ties = FALSE so that when there are more than one possibility for a control, it will select a random control
#replace = FALSE so that once a record has been selected for control, it can't be selected again
set.seed(1234)
cc_match <- Matching::Match(Tr = data40$diabetes,
                            M = 1,
                            X = data40$agecat,
                            exact=TRUE,
                            ties = FALSE,
                            replace = FALSE)
summary(cc_match)

#Identify the cases and which case-control pair they are in (matchset)
ii<-match(cc_match$index.treated,data40$id)
all(cc_match$index.treated==data40$id[ii])
cases<-cbind(matchset=1:length(ii),data40[ii,])

#Identify the controls and which case-control pair they are in (matchset)
jj<-match(cc_match$index.control,data40$id)
all(cc_match$index.control==data40$id[jj])
controls<-cbind(matchset=1:length(jj),data40[jj,])

#Have the cases and controls identified into a new dataset 
matched.fin <- rbind(cases,controls)


################################################################################
##                               Question 1 (i)      
##
##-(i) Create the paired 2-by-2 table of the association between CHD and 
##     Diabetes for individuals aged 40 years and above.
##
################################################################################

#make paired 2by2 table - matched
tab.mcc<-table(cases$prevchd,controls$prevchd)
tab.mcc


################################################################################
##                               Question 1 (ii)      
##
##-(ii) Conduct the McNemar test of association using your software or your own 
##      calculations based on the counts in the table, or both.
##
################################################################################

mcnemar.test(tab.mcc,correct=FALSE) 


################################################################################
##                               Question 1 (iii)      
##
##-(iii) Calculate the paired OR with the 95% confidence interval using your 
##       software or your own calculations based on the counts in the table, 
##       or both.
##
################################################################################


#2x2 matched data
tab.mcc

#The matched OR
CALC_MATCHED_OR(tab.mcc[2,2],tab.mcc[2,1],tab.mcc[1,2],tab.mcc[1,1])


################################################################################
##                               Question 2      
##
##-2. The dataset "RSV_data_exercise.dta" contains data from the 1:2 matched 
##    case-control study of severe RSV disease in infants in Kenya (Nyiro JU, 
##    Sande CJ, et al. Absence of Association between Cord Specific Antibody 
##    Levels and Severe Respiratory Syncytial Virus (RSV) Disease in Early 
##    Infants: A Case Control Study from Coastal Kenya. PLoS One. 2016 Nov 
##    16;11(11):e0166706).  The variables of interest for this exercise are:
##    -matchset:  a unique number identifying a case and their controls 	
##    -controlno: control number (1,2)
##    -case:      indicator for case (1) or control (0) 
##    -ntitre0:   antibody titre (on log scale)
##    -bwt:       birth weight (Kg)
##    -underwt:   indicator for low birth weight 
##    -gest_agew: gestational age (weeks) 
##    -premature: indicator for prematurity
##
################################################################################

################################################################################
##                               Question 2(i)      
##
##-(i) Open this data set and create an indicator for a high titre (>= the 
##     median rounded to 2 decimal place).  Save a temporary copy of the data.
################################################################################

#Read in the data
data2 <- haven::read_dta("RSV_data_exercise.dta")

#Create an indicator for a high titre (>= the median rounded to 2 decimal place).  
#New variable ID_TITRE, 0=low, 1=high
data2$ID_TITRE <- ifelse(data2$ntitre0 < round(median(data2$ntitre0),2), 0, 1)
table(data2$ID_TITRE)


################################################################################
##                               Question 2(ii)      
##
##-(ii) Drop one control from each set (Note that it may not be necessary to 
##      use a "seed" this time if we make some reasonable assumption!). Save 
##      a temporary copy of the data. 
##
##      Examine the 2-by-2 table of the case-control pairs and from this table, 
##      compute the paired OR and 95% confidence interval for the association 
##      between high titre and RSV.
################################################################################

#split dataset into 2, case and controls
data2.controls <- data2[which(data2$controlno==1),]
data2.cases <- data2[which(is.na(data2$controlno)),]

#join the control and cases back together into one dataset
data2.small <- rbind(data2.controls,data2.cases)
dim(data2.small)

#make paired 2by2 table - matched
#use function "matchTab" from the library "epiDisplay"
mcc_tab2 <- epiDisplay::matchTab (case = data2.small$case, 
                                  exposed = data2.small$ID_TITRE, 
                                  strata = data2.small$matchset,
                                  decimal = 3)
mcc_tab2

#==Alternative approach that randomly drop the controls
data2.controls <- data2[which(!is.na(data2$controlno)),]
data2.cases <- data2[which(is.na(data2$controlno)),]

set.seed(2307)
data2.controls.dropped <- data2.controls %>% group_by(matchset) %>% slice_sample(n=1)
table(data2.controls.dropped$controlno)

#join the control and cases back together into one dataset
data2.small <- rbind(data2.controls.dropped,data2.cases)
dim(data2.small)

#make paired 2by2 table - matched
#use function "matchTab" from the library "epiDisplay"
mcc_tab2 <- epiDisplay::matchTab (case = data2.small$case, 
                                  exposed = data2.small$ID_TITRE, 
                                  strata = data2.small$matchset,
                                  decimal = 3)
mcc_tab2


################################################################################
##                               Question 2(iii)      
##
##-(iii) Repeat the computation of the paired OR in (ii) using conditional 
##       logistic regression.
################################################################################

#Conduct logistic regression using "clogit" function in "survival" library
c_log1 <- clogit(case ~ ID_TITRE + strata(matchset),
                 data = data2.small)
#Display results of conditional logistic regression
summary(c_log1)


################################################################################
##                               Question 2(iv)      
##
##-(iv) For the continuous measure of antibody levels, use the temporary data 
##      set from (i) with all the infants from the 1:2 matched study, reproduce 
##      the results described in the following text from the paper by 
##      Nyiro et al:
##  
##      The overall reduction in risk of RSV disease per log2PRNTunit increase 
##      in cord blood antibody titres in all infants was 
##       (OR = 0.79, 95% CI 0.471.31; P = 0.4).
##      The log2PRNT antibody titre in cord blood showed an increase with 
##      increasing gestational age. However, adjusting for prematurity 
##      (i.e. gestational age < 37 weeks) in the conditional logistic 
##      regression analysis did not have an appreciable effect on the 
##      outcome (OR = 0.67, 95% CI 0.192.4; P = 0.5). 
################################################################################

#do conditional logistic regression with full dataset without adjustment
c_log2 <- clogit(case ~ ntitre0 + strata(matchset),
                 data = data2)
summary(c_log2)

#adjust for premature
c_log3 <- clogit(case ~ ntitre0 + premature + strata(matchset),
                 data = data2)
summary(c_log3)
