//----------------------------------------------------------------------------//
//=Purpose: Exercise 2.3 of Beyond Classic Designs & Analysis for Health      //
//          Data in Singapore (27 June to 8 July 2022)                        //
//
//=Stata package required:
//  - ccmatch
//
//=Data required: 
//  - 2.1_framingham_exercises.dta
//  - RSV_data_exercise.dta
//
//= Written by:
//  - Zihan Dong
// Updated by:
//  - Chuen Seng Tan
//  - Marie Reilly
//
// Last Run: June 9, 2022 (Marie)
//
//----------------------------------------------------------------------------//

//-Set the working directory to the data folder where the datasets are saved:

*cd "D:/nbox/Education/Marie_short_course/Singapore course 2022/20220602/exercises/data"

cd  "/Users/marrei/Documents/Singapore_course/data/"



////////////////////////////////////////////////////////////////////////////////
//                               Question 1      
//
//-1. Using the same data as for Exercise 2.1, generate a new age category 
//    variable with age in decades agecat2 (< 40, 40-49, 50-59, 60-70). Select 
//    a matched case-control sample of diabetes cases and one control per case, 
//    matched on agecat2. Make sure to set a “seed” before the sampling so that 
//    you can reproduce the exact same selection if necessary.
//
//    Save as a temporary data set. We will use these data to examine the 
//    association of prevalent diabetes with prevalent CHD.
////////////////////////////////////////////////////////////////////////////////


*Create a matched case-control sample of diabetes cases and one control per case and save this dataset:

*Load the data and describe the variables


use 2.1_framingham_exercises.dta, clear
describe

* check the number of diabetes cases (121):
tab diabetes


*generate "agecat2" and save a temporary dataset:

gen agecat2=0 if age<40
replace agecat2=1 if age>=40 & age<=49
replace agecat2=2 if age>=50 & age<=59
replace agecat2=3 if age>=60 & age<=70
codebook agecat2

save temp, replace



*There are two ways to match:*

*Method 1: "ccmatch"*

set seed 1810
gen randid=runiform()
ccmatch agecat2, id(randid) cc(diabetes)
drop if match==.
reshape wide sex age prevchd prevhyp anychd agecat randid agecat2 match_id, i(match) j(diabetes)
 save tempdata_ccmatch, replace
 
 

*Method 2: "merge"*

*separate cases from controls, distinguish variable names of cases vs controls, 
* sort cases and control randomly within age categories, join on agecat2:

use temp, clear

* prepare controls
set seed 1810
gen randid=runiform()
preserve
keep if diabetes == 0
rename * *_control
rename agecat2_control agecat2
sort agecat2 randid
by agecat2:gen obsn=_n
tempfile controls
count
save tempcontrols.dta, replace

* prepare cases
restore
keep if diabetes == 1
rename * *_case
rename agecat2_case agecat2
sort agecat2 randid
by agecat2:gen obsn=_n
count

* merge cases and controls sequentially
merge 1:1 agecat2 obsn using tempcontrols.dta
keep if _merge==3

*save the matched dataset:

save tempdata_merge, replace



////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (i)      
//
//-(i) Create the paired 2-by-2 table of the association between CHD and 
//     Diabetes for individuals aged 40 years and above.
//
////////////////////////////////////////////////////////////////////////////////

*Load the data
use tempdata_ccmatch, clear

*drop people aged<40:
drop if agecat2==0

*Create paired 2-by-2 table and conduct McNemar test: 	
mcc prevchd_case prevchd_control


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (ii)      
//
//-(ii) Conduct the McNemar test of association using your software or your own 
//      calculations based on the counts in the table, or both.
//
////////////////////////////////////////////////////////////////////////////////
*see (i)


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (iii)      
//
//-(iii) Calculate the paired OR with the 95% confidence interval using your 
//       software or your own calculations based on the counts in the table, 
//       or both.
//
////////////////////////////////////////////////////////////////////////////////
*see (i)


////////////////////////////////////////////////////////////////////////////////
//                               Question 2      
//
//-2. The dataset “RSV_data_exercise.dta” contains data from the 1:2 matched 
//    case-control study of severe RSV disease in infants in Kenya (Nyiro JU, 
//    Sande CJ, et al. Absence of Association between Cord Specific Antibody 
//    Levels and Severe Respiratory Syncytial Virus (RSV) Disease in Early 
//    Infants: A Case Control Study from Coastal Kenya. PLoS One. 2016 Nov 
//    16;11(11):e0166706).  The variables of interest for this exercise are:
//    -matchset:  a unique number identifying a case and their controls 	
//    -controlno: control number (1,2)
//    -case:      indicator for case (1) or control (0) 
//    -ntitre0:   antibody titre (on log scale)
//    -bwt:       birth weight (Kg)
//    -underwt:   indicator for low birth weight 
//    -gest_agew: gestational age (weeks) 
//    -premature: indicator for prematurity
//
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//                               Question 2(i)      
//
//-(i) Open this data set and create an indicator for a high titre (>= the 
//     median rounded to 2 decimal place).  Save a temporary copy of the data.
////////////////////////////////////////////////////////////////////////////////

*Load the dataset
use RSV_data_exercise.dta, clear

*Generate the indicator and save a temporary copy
codebook ntitre0
gen ntitre0hi=1 if ntitre0 >=10.85 & ntitre0!=.
replace ntitre0hi=0 if ntitre0 < 10.85
tab ntitre0hi
save hightitre, replace


////////////////////////////////////////////////////////////////////////////////
//                               Question 2(ii)      
//
//-(ii) Drop one control from each set (Note that it may not be necessary to 
//      use a “seed” this time if we make some reasonable assumption!). Save 
//      a temporary copy of the data. 
//
//      Examine the 2-by-2 table of the case-control pairs and from this table, 
//      compute the paired OR and 95% confidence interval for the association 
//      between high titre and RSV.
////////////////////////////////////////////////////////////////////////////////

*drop one control and save the dataset:

use hightitre, clear
drop if controlno==1
save tempcc, replace

*To create paired table we have to reshape the dataset:

drop bwt gest_agew underwt ntitre0
reshape wide controlno premature ntitre0hi, i(matchset) j(case) 

*generate paired 2-by-2 table and get paired OR computed from the discordant pairs:

mcc ntitre0hi1 ntitre0hi0


////////////////////////////////////////////////////////////////////////////////
//                               Question 2(iii)      
//
//-(iii) Repeat the computation of the paired OR in (ii) using conditional 
//       logistic regression.
////////////////////////////////////////////////////////////////////////////////

use tempcc, clear
clogit case ntitre0hi, group(matchset) or


////////////////////////////////////////////////////////////////////////////////
//                               Question 2(iv)      
//
//-(iv) For the continuous measure of antibody levels, use the temporary data 
//      set from (i) with all the infants from the 1:2 matched study, reproduce 
//      the results described in the following text from the paper by 
//      Nyiro et al:
//  
//      The overall reduction in risk of RSV disease per log2PRNTunit increase 
//      in cord blood antibody titres in all infants was 
//       (OR = 0.79, 95% CI 0.47±1.31; P = 0.4).
//      The log2PRNT antibody titre in cord blood showed an increase with 
//      increasing gestational age. However, adjusting for prematurity 
//      (i.e. gestational age < 37 weeks) in the conditional logistic 
//      regression analysis did not have an appreciable effect on the 
//      outcome (OR = 0.67, 95% CI 0.19±2.4; P = 0.5). 
////////////////////////////////////////////////////////////////////////////////

use hightitre, clear

clogit case ntitre0, group(matchset) or

clogit case ntitre0 premature, group(matchset) or

